# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class OfferManagementApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def change_publication_status_using_put(self, command_id, publication_change_command_dto, **kwargs):  # noqa: E501
        """Batch offer publish / unpublish  # noqa: E501

        Use this resource to modify multiple offers publication at once. <a href=\"../../sale/#step-8-offer-publication-commands\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_publication_status_using_put(command_id, publication_change_command_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str command_id: Command identifier. (required)
        :param PublicationChangeCommandDto publication_change_command_dto: publicationChangeCommandDto (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GeneralReport
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.change_publication_status_using_put_with_http_info(command_id, publication_change_command_dto, **kwargs)  # noqa: E501

    def change_publication_status_using_put_with_http_info(self, command_id, publication_change_command_dto, **kwargs):  # noqa: E501
        """Batch offer publish / unpublish  # noqa: E501

        Use this resource to modify multiple offers publication at once. <a href=\"../../sale/#step-8-offer-publication-commands\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_publication_status_using_put_with_http_info(command_id, publication_change_command_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str command_id: Command identifier. (required)
        :param PublicationChangeCommandDto publication_change_command_dto: publicationChangeCommandDto (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GeneralReport, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['command_id', 'publication_change_command_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_publication_status_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'command_id' is set
        if self.api_client.client_side_validation and ('command_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['command_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `command_id` when calling `change_publication_status_using_put`")  # noqa: E501
        # verify the required parameter 'publication_change_command_dto' is set
        if self.api_client.client_side_validation and ('publication_change_command_dto' not in local_var_params or  # noqa: E501
                                                        local_var_params['publication_change_command_dto'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `publication_change_command_dto` when calling `change_publication_status_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'command_id' in local_var_params:
            path_params['commandId'] = local_var_params['command_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'publication_change_command_dto' in local_var_params:
            body_params = local_var_params['publication_change_command_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-publication-commands/{commandId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GeneralReport',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_change_price_command_using_put(self, offer_id, command_id, change_price_without_output, **kwargs):  # noqa: E501
        """Modify the Buy Now price in an offer  # noqa: E501

        Use this resource to change the Buy Now price in a single offer. <a href=\"../../news/2016-08-01-zmiana-ceny/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_change_price_command_using_put(offer_id, command_id, change_price_without_output, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: The offer identifier. (required)
        :param str command_id: The unique command id generated by you. (required)
        :param ChangePriceWithoutOutput change_price_without_output: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ChangePrice
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_change_price_command_using_put_with_http_info(offer_id, command_id, change_price_without_output, **kwargs)  # noqa: E501

    def create_change_price_command_using_put_with_http_info(self, offer_id, command_id, change_price_without_output, **kwargs):  # noqa: E501
        """Modify the Buy Now price in an offer  # noqa: E501

        Use this resource to change the Buy Now price in a single offer. <a href=\"../../news/2016-08-01-zmiana-ceny/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_change_price_command_using_put_with_http_info(offer_id, command_id, change_price_without_output, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: The offer identifier. (required)
        :param str command_id: The unique command id generated by you. (required)
        :param ChangePriceWithoutOutput change_price_without_output: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ChangePrice, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id', 'command_id', 'change_price_without_output']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_change_price_command_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_id' is set
        if self.api_client.client_side_validation and ('offer_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_id` when calling `create_change_price_command_using_put`")  # noqa: E501
        # verify the required parameter 'command_id' is set
        if self.api_client.client_side_validation and ('command_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['command_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `command_id` when calling `create_change_price_command_using_put`")  # noqa: E501
        # verify the required parameter 'change_price_without_output' is set
        if self.api_client.client_side_validation and ('change_price_without_output' not in local_var_params or  # noqa: E501
                                                        local_var_params['change_price_without_output'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `change_price_without_output` when calling `create_change_price_command_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'offer_id' in local_var_params:
            path_params['offerId'] = local_var_params['offer_id']  # noqa: E501
        if 'command_id' in local_var_params:
            path_params['commandId'] = local_var_params['command_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_price_without_output' in local_var_params:
            body_params = local_var_params['change_price_without_output']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/offers/{offerId}/change-price-commands/{commandId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChangePrice',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_offer_using_post(self, offer, **kwargs):  # noqa: E501
        """Create a draft offer  # noqa: E501

        Use this resource to create a draft offer. <a href=\"../../sale/#step-6-draft\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_offer_using_post(offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Offer offer: offer (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Offer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_offer_using_post_with_http_info(offer, **kwargs)  # noqa: E501

    def create_offer_using_post_with_http_info(self, offer, **kwargs):  # noqa: E501
        """Create a draft offer  # noqa: E501

        Use this resource to create a draft offer. <a href=\"../../sale/#step-6-draft\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_offer_using_post_with_http_info(offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Offer offer: offer (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Offer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_offer_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer' is set
        if self.api_client.client_side_validation and ('offer' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer` when calling `create_offer_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'offer' in local_var_params:
            body_params = local_var_params['offer']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Offer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_offer_using_delete(self, offer_id, **kwargs):  # noqa: E501
        """Delete a draft offer  # noqa: E501

        Use this resource to delete a draft offer. <a href=\"../../news/2018-10-09_draft_delete/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_offer_using_delete(offer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_offer_using_delete_with_http_info(offer_id, **kwargs)  # noqa: E501

    def delete_offer_using_delete_with_http_info(self, offer_id, **kwargs):  # noqa: E501
        """Delete a draft offer  # noqa: E501

        Use this resource to delete a draft offer. <a href=\"../../news/2018-10-09_draft_delete/\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_offer_using_delete_with_http_info(offer_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_offer_using_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_id' is set
        if self.api_client.client_side_validation and ('offer_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_id` when calling `delete_offer_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'offer_id' in local_var_params:
            path_params['offerId'] = local_var_params['offer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offers/{offerId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_publication_report_using_get(self, command_id, **kwargs):  # noqa: E501
        """Publish command summary  # noqa: E501

        Use this resource to retrieve information about the offer listing statuses. You will receive a summary with a number of correctly listed offers and errors. <a href=\"../../sale/#step-8-offer-publication-commands\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_publication_report_using_get(command_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str command_id: Command identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GeneralReport
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_publication_report_using_get_with_http_info(command_id, **kwargs)  # noqa: E501

    def get_publication_report_using_get_with_http_info(self, command_id, **kwargs):  # noqa: E501
        """Publish command summary  # noqa: E501

        Use this resource to retrieve information about the offer listing statuses. You will receive a summary with a number of correctly listed offers and errors. <a href=\"../../sale/#step-8-offer-publication-commands\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_publication_report_using_get_with_http_info(command_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str command_id: Command identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GeneralReport, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['command_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_publication_report_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'command_id' is set
        if self.api_client.client_side_validation and ('command_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['command_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `command_id` when calling `get_publication_report_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'command_id' in local_var_params:
            path_params['commandId'] = local_var_params['command_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-publication-commands/{commandId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GeneralReport',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_publication_tasks_using_get(self, command_id, **kwargs):  # noqa: E501
        """Publish command detailed report  # noqa: E501

        Use this resource to retrieve information about the offer statuses on the site (Defaults: limit = 100, offset = 0). <a href=\"../../sale/#step-8-offer-publication-commands\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_publication_tasks_using_get(command_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str command_id: Command identifier. (required)
        :param int limit: The limit of elements in the response.
        :param int offset: The offset of elements in the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskReport
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_publication_tasks_using_get_with_http_info(command_id, **kwargs)  # noqa: E501

    def get_publication_tasks_using_get_with_http_info(self, command_id, **kwargs):  # noqa: E501
        """Publish command detailed report  # noqa: E501

        Use this resource to retrieve information about the offer statuses on the site (Defaults: limit = 100, offset = 0). <a href=\"../../sale/#step-8-offer-publication-commands\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_publication_tasks_using_get_with_http_info(command_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str command_id: Command identifier. (required)
        :param int limit: The limit of elements in the response.
        :param int offset: The offset of elements in the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskReport, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['command_id', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_publication_tasks_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'command_id' is set
        if self.api_client.client_side_validation and ('command_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['command_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `command_id` when calling `get_publication_tasks_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'command_id' in local_var_params:
            path_params['commandId'] = local_var_params['command_id']  # noqa: E501

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-publication-commands/{commandId}/tasks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskReport',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_offer_using_put(self, offer_id, offer, **kwargs):  # noqa: E501
        """Complete a draft offer or edit an offer  # noqa: E501

        Use this resource to complete a draft offer or edit ongoing offers. <a href=\"../../sale/#step-7-complete\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_offer_using_put(offer_id, offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer identifier. (required)
        :param Offer offer: offer (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Offer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_offer_using_put_with_http_info(offer_id, offer, **kwargs)  # noqa: E501

    def update_offer_using_put_with_http_info(self, offer_id, offer, **kwargs):  # noqa: E501
        """Complete a draft offer or edit an offer  # noqa: E501

        Use this resource to complete a draft offer or edit ongoing offers. <a href=\"../../sale/#step-7-complete\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_offer_using_put_with_http_info(offer_id, offer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str offer_id: Offer identifier. (required)
        :param Offer offer: offer (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Offer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_id', 'offer']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_offer_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_id' is set
        if self.api_client.client_side_validation and ('offer_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_id` when calling `update_offer_using_put`")  # noqa: E501
        # verify the required parameter 'offer' is set
        if self.api_client.client_side_validation and ('offer' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer` when calling `update_offer_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'offer_id' in local_var_params:
            path_params['offerId'] = local_var_params['offer_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'offer' in local_var_params:
            body_params = local_var_params['offer']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offers/{offerId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Offer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class CompatibilityListApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_categories_that_support_compatibility_list(self, **kwargs):  # noqa: E501
        """Get list of categories where compatibility list is supported  # noqa: E501

        Compatibility list is available in particular categories, this resource allows to get the list of these categories with additional details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_categories_that_support_compatibility_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CompatibilityListSupportedCategoriesDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_categories_that_support_compatibility_list_with_http_info(**kwargs)  # noqa: E501

    def get_categories_that_support_compatibility_list_with_http_info(self, **kwargs):  # noqa: E501
        """Get list of categories where compatibility list is supported  # noqa: E501

        Compatibility list is available in particular categories, this resource allows to get the list of these categories with additional details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_categories_that_support_compatibility_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CompatibilityListSupportedCategoriesDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_categories_that_support_compatibility_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/compatibility-list/supported-categories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CompatibilityListSupportedCategoriesDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_compatible_products(self, type, **kwargs):  # noqa: E501
        """Get list of compatible products  # noqa: E501

        Resource allows to fetch compatible products of given type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_compatible_products(type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str type: Type of compatible products. You can find available types in the response for the GET <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatibility-list~1supported-categories/get\">supported-categories</a> resource. You can use value provided in `itemsType`, for categories where `inputType=ID`. (required)
        :param str if_modified_since: Date of last data modification. If data has been modified after specified date, full set of data is returned. If header is not specified, full set of data is returned. Date has to be provided in HTTP-date format. Header is ignored if `phrase` parameter is used.
        :param str group_id: Group identifier from `/sale/compatible-products/groups` resource. Parameter is required when parameter `tecdoc.kTypNr` or `tecdoc.nTypNr` or `phrase` is not specified.
        :param str tecdoc_k_typ_nr: Identifier of passenger vehicle (kTypNr) from TecDoc database. When used, `group.id` parameter is ignored.
        :param str tecdoc_n_typ_nr: Identifier of commercial vehicle (nTypNr) from TecDoc database. When used, `group.id` parameter is ignored.
        :param str phrase: Query for compatible products. When used, parameters: `group.id`, `limit`, `offset` and header `If-Modified-Since` are ignored.
        :param int limit: The limit of returned items. If `phrase` parameter is present, parameter is ignored and maximum value is set to `200`.
        :param int offset: The offset of returned items. If `phrase` parameter is present, parameter is ignored.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CompatibleProductsListDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_compatible_products_with_http_info(type, **kwargs)  # noqa: E501

    def get_compatible_products_with_http_info(self, type, **kwargs):  # noqa: E501
        """Get list of compatible products  # noqa: E501

        Resource allows to fetch compatible products of given type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_compatible_products_with_http_info(type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str type: Type of compatible products. You can find available types in the response for the GET <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatibility-list~1supported-categories/get\">supported-categories</a> resource. You can use value provided in `itemsType`, for categories where `inputType=ID`. (required)
        :param str if_modified_since: Date of last data modification. If data has been modified after specified date, full set of data is returned. If header is not specified, full set of data is returned. Date has to be provided in HTTP-date format. Header is ignored if `phrase` parameter is used.
        :param str group_id: Group identifier from `/sale/compatible-products/groups` resource. Parameter is required when parameter `tecdoc.kTypNr` or `tecdoc.nTypNr` or `phrase` is not specified.
        :param str tecdoc_k_typ_nr: Identifier of passenger vehicle (kTypNr) from TecDoc database. When used, `group.id` parameter is ignored.
        :param str tecdoc_n_typ_nr: Identifier of commercial vehicle (nTypNr) from TecDoc database. When used, `group.id` parameter is ignored.
        :param str phrase: Query for compatible products. When used, parameters: `group.id`, `limit`, `offset` and header `If-Modified-Since` are ignored.
        :param int limit: The limit of returned items. If `phrase` parameter is present, parameter is ignored and maximum value is set to `200`.
        :param int offset: The offset of returned items. If `phrase` parameter is present, parameter is ignored.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CompatibleProductsListDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['type', 'if_modified_since', 'group_id', 'tecdoc_k_typ_nr', 'tecdoc_n_typ_nr', 'phrase', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_compatible_products" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'type' is set
        if self.api_client.client_side_validation and ('type' not in local_var_params or  # noqa: E501
                                                        local_var_params['type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `type` when calling `get_compatible_products`")  # noqa: E501

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 200:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_compatible_products`, must be a value less than or equal to `200`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_compatible_products`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_compatible_products`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('type', local_var_params['type']))  # noqa: E501
        if 'group_id' in local_var_params and local_var_params['group_id'] is not None:  # noqa: E501
            query_params.append(('group.id', local_var_params['group_id']))  # noqa: E501
        if 'tecdoc_k_typ_nr' in local_var_params and local_var_params['tecdoc_k_typ_nr'] is not None:  # noqa: E501
            query_params.append(('tecdoc.kTypNr', local_var_params['tecdoc_k_typ_nr']))  # noqa: E501
        if 'tecdoc_n_typ_nr' in local_var_params and local_var_params['tecdoc_n_typ_nr'] is not None:  # noqa: E501
            query_params.append(('tecdoc.nTypNr', local_var_params['tecdoc_n_typ_nr']))  # noqa: E501
        if 'phrase' in local_var_params and local_var_params['phrase'] is not None:  # noqa: E501
            query_params.append(('phrase', local_var_params['phrase']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}
        if 'if_modified_since' in local_var_params:
            header_params['If-Modified-Since'] = local_var_params['if_modified_since']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/compatible-products', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CompatibleProductsListDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_compatible_products_groups(self, type, **kwargs):  # noqa: E501
        """Get list of compatible product groups  # noqa: E501

        Compatible products are organized in groups, this resource allows to browse these groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_compatible_products_groups(type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str type: Type of compatible products. You can find available types in the response for the GET <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatibility-list~1supported-categories/get\">supported-categories</a> resource. You can use value provided in `itemsType`, for categories where `inputType=ID`. (required)
        :param str if_modified_since: Date of last data modification. If data has been modified after specified date, full set of data is returned. If header is not specified, full set of data is returned. Date has to be provided in HTTP-date format.
        :param int limit: The limit of returned items.
        :param int offset: The offset of returned items.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CompatibleProductsGroupsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_compatible_products_groups_with_http_info(type, **kwargs)  # noqa: E501

    def get_compatible_products_groups_with_http_info(self, type, **kwargs):  # noqa: E501
        """Get list of compatible product groups  # noqa: E501

        Compatible products are organized in groups, this resource allows to browse these groups.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_compatible_products_groups_with_http_info(type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str type: Type of compatible products. You can find available types in the response for the GET <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatibility-list~1supported-categories/get\">supported-categories</a> resource. You can use value provided in `itemsType`, for categories where `inputType=ID`. (required)
        :param str if_modified_since: Date of last data modification. If data has been modified after specified date, full set of data is returned. If header is not specified, full set of data is returned. Date has to be provided in HTTP-date format.
        :param int limit: The limit of returned items.
        :param int offset: The offset of returned items.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CompatibleProductsGroupsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['type', 'if_modified_since', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_compatible_products_groups" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'type' is set
        if self.api_client.client_side_validation and ('type' not in local_var_params or  # noqa: E501
                                                        local_var_params['type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `type` when calling `get_compatible_products_groups`")  # noqa: E501

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 200:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_compatible_products_groups`, must be a value less than or equal to `200`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_compatible_products_groups`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_compatible_products_groups`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('type', local_var_params['type']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}
        if 'if_modified_since' in local_var_params:
            header_params['If-Modified-Since'] = local_var_params['if_modified_since']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/compatible-products/groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CompatibleProductsGroupsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class AverageRates(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'delivery': 'float',
        'delivery_cost': 'float',
        'description': 'float',
        'service': 'float'
    }

    attribute_map = {
        'delivery': 'delivery',
        'delivery_cost': 'deliveryCost',
        'description': 'description',
        'service': 'service'
    }

    def __init__(self, delivery=None, delivery_cost=None, description=None, service=None, local_vars_configuration=None):  # noqa: E501
        """AverageRates - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._delivery = None
        self._delivery_cost = None
        self._description = None
        self._service = None
        self.discriminator = None

        if delivery is not None:
            self.delivery = delivery
        if delivery_cost is not None:
            self.delivery_cost = delivery_cost
        if description is not None:
            self.description = description
        if service is not None:
            self.service = service

    @property
    def delivery(self):
        """Gets the delivery of this AverageRates.  # noqa: E501

        The average value of delivery rate.  # noqa: E501

        :return: The delivery of this AverageRates.  # noqa: E501
        :rtype: float
        """
        return self._delivery

    @delivery.setter
    def delivery(self, delivery):
        """Sets the delivery of this AverageRates.

        The average value of delivery rate.  # noqa: E501

        :param delivery: The delivery of this AverageRates.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                delivery is not None and delivery > 5):  # noqa: E501
            raise ValueError("Invalid value for `delivery`, must be a value less than or equal to `5`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                delivery is not None and delivery < 0):  # noqa: E501
            raise ValueError("Invalid value for `delivery`, must be a value greater than or equal to `0`")  # noqa: E501

        self._delivery = delivery

    @property
    def delivery_cost(self):
        """Gets the delivery_cost of this AverageRates.  # noqa: E501

        The average value of delivery cost rate.  # noqa: E501

        :return: The delivery_cost of this AverageRates.  # noqa: E501
        :rtype: float
        """
        return self._delivery_cost

    @delivery_cost.setter
    def delivery_cost(self, delivery_cost):
        """Sets the delivery_cost of this AverageRates.

        The average value of delivery cost rate.  # noqa: E501

        :param delivery_cost: The delivery_cost of this AverageRates.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                delivery_cost is not None and delivery_cost > 5):  # noqa: E501
            raise ValueError("Invalid value for `delivery_cost`, must be a value less than or equal to `5`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                delivery_cost is not None and delivery_cost < 0):  # noqa: E501
            raise ValueError("Invalid value for `delivery_cost`, must be a value greater than or equal to `0`")  # noqa: E501

        self._delivery_cost = delivery_cost

    @property
    def description(self):
        """Gets the description of this AverageRates.  # noqa: E501

        The average value of description rate.  # noqa: E501

        :return: The description of this AverageRates.  # noqa: E501
        :rtype: float
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AverageRates.

        The average value of description rate.  # noqa: E501

        :param description: The description of this AverageRates.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and description > 5):  # noqa: E501
            raise ValueError("Invalid value for `description`, must be a value less than or equal to `5`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and description < 0):  # noqa: E501
            raise ValueError("Invalid value for `description`, must be a value greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def service(self):
        """Gets the service of this AverageRates.  # noqa: E501

        The average value of service rate.  # noqa: E501

        :return: The service of this AverageRates.  # noqa: E501
        :rtype: float
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this AverageRates.

        The average value of service rate.  # noqa: E501

        :param service: The service of this AverageRates.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                service is not None and service > 5):  # noqa: E501
            raise ValueError("Invalid value for `service`, must be a value less than or equal to `5`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                service is not None and service < 0):  # noqa: E501
            raise ValueError("Invalid value for `service`, must be a value greater than or equal to `0`")  # noqa: E501

        self._service = service

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AverageRates):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AverageRates):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class Delivery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'additional_info': 'str',
        'handling_time': 'str',
        'shipment_date': 'datetime',
        'shipping_rates': 'JustId'
    }

    attribute_map = {
        'additional_info': 'additionalInfo',
        'handling_time': 'handlingTime',
        'shipment_date': 'shipmentDate',
        'shipping_rates': 'shippingRates'
    }

    def __init__(self, additional_info=None, handling_time=None, shipment_date=None, shipping_rates=None, local_vars_configuration=None):  # noqa: E501
        """Delivery - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._additional_info = None
        self._handling_time = None
        self._shipment_date = None
        self._shipping_rates = None
        self.discriminator = None

        if additional_info is not None:
            self.additional_info = additional_info
        if handling_time is not None:
            self.handling_time = handling_time
        if shipment_date is not None:
            self.shipment_date = shipment_date
        if shipping_rates is not None:
            self.shipping_rates = shipping_rates

    @property
    def additional_info(self):
        """Gets the additional_info of this Delivery.  # noqa: E501


        :return: The additional_info of this Delivery.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this Delivery.


        :param additional_info: The additional_info of this Delivery.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                additional_info is not None and len(additional_info) > 650):
            raise ValueError("Invalid value for `additional_info`, length must be less than or equal to `650`")  # noqa: E501

        self._additional_info = additional_info

    @property
    def handling_time(self):
        """Gets the handling_time of this Delivery.  # noqa: E501

        Handling time, ISO 8601 duration format  # noqa: E501

        :return: The handling_time of this Delivery.  # noqa: E501
        :rtype: str
        """
        return self._handling_time

    @handling_time.setter
    def handling_time(self, handling_time):
        """Sets the handling_time of this Delivery.

        Handling time, ISO 8601 duration format  # noqa: E501

        :param handling_time: The handling_time of this Delivery.  # noqa: E501
        :type: str
        """

        self._handling_time = handling_time

    @property
    def shipment_date(self):
        """Gets the shipment_date of this Delivery.  # noqa: E501

        Shipment date, Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ  # noqa: E501

        :return: The shipment_date of this Delivery.  # noqa: E501
        :rtype: datetime
        """
        return self._shipment_date

    @shipment_date.setter
    def shipment_date(self, shipment_date):
        """Sets the shipment_date of this Delivery.

        Shipment date, Format (ISO 8601) - yyyy-MM-dd'T'HH:mm:ss.SSSZ  # noqa: E501

        :param shipment_date: The shipment_date of this Delivery.  # noqa: E501
        :type: datetime
        """

        self._shipment_date = shipment_date

    @property
    def shipping_rates(self):
        """Gets the shipping_rates of this Delivery.  # noqa: E501


        :return: The shipping_rates of this Delivery.  # noqa: E501
        :rtype: JustId
        """
        return self._shipping_rates

    @shipping_rates.setter
    def shipping_rates(self, shipping_rates):
        """Sets the shipping_rates of this Delivery.


        :param shipping_rates: The shipping_rates of this Delivery.  # noqa: E501
        :type: JustId
        """

        self._shipping_rates = shipping_rates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Delivery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Delivery):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.line_item_id_mappings import LineItemIdMappings  # noqa: E501
from allegro_api.rest import ApiException

class TestLineItemIdMappings(unittest.TestCase):
    """LineItemIdMappings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LineItemIdMappings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.line_item_id_mappings.LineItemIdMappings()  # noqa: E501
        if include_optional :
            return LineItemIdMappings(
                mappings = [
                    allegro_api.models.line_item_id_mappings_mappings.LineItemIdMappings_mappings(
                        deal_id = '12345678', 
                        line_item_id = '4e9d1d43-0da5-466e-9c4a-679625b7a617', )
                    ]
            )
        else :
            return LineItemIdMappings(
        )

    def testLineItemIdMappings(self):
        """Test LineItemIdMappings"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.user_rating_summary_response import UserRatingSummaryResponse  # noqa: E501
from allegro_api.rest import ApiException

class TestUserRatingSummaryResponse(unittest.TestCase):
    """UserRatingSummaryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserRatingSummaryResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.user_rating_summary_response.UserRatingSummaryResponse()  # noqa: E501
        if include_optional :
            return UserRatingSummaryResponse(
                average_rates = allegro_api.models.average_rates.AverageRates(
                    delivery = 4.7, 
                    delivery_cost = 5, 
                    description = 4.5, 
                    service = 4.8, ), 
                not_recommended = allegro_api.models.user_rating_summary_response_not_recommended.UserRatingSummaryResponse_notRecommended(
                    total = 100, 
                    unique = 80, ), 
                recommended = allegro_api.models.user_rating_summary_response_recommended.UserRatingSummaryResponse_recommended(
                    total = 100, 
                    unique = 75, ), 
                recommended_percentage = '99,8'
            )
        else :
            return UserRatingSummaryResponse(
                not_recommended = allegro_api.models.user_rating_summary_response_not_recommended.UserRatingSummaryResponse_notRecommended(
                    total = 100, 
                    unique = 80, ),
                recommended = allegro_api.models.user_rating_summary_response_recommended.UserRatingSummaryResponse_recommended(
                    total = 100, 
                    unique = 75, ),
                recommended_percentage = '99,8',
        )

    def testUserRatingSummaryResponse(self):
        """Test UserRatingSummaryResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.search_result import SearchResult  # noqa: E501
from allegro_api.rest import ApiException

class TestSearchResult(unittest.TestCase):
    """SearchResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SearchResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.search_result.SearchResult()  # noqa: E501
        if include_optional :
            return SearchResult(
                pos_list = [
                    allegro_api.models.pos.Pos(
                        id = '0', 
                        external_id = '0', 
                        name = '0', 
                        seller = allegro_api.models.seller.Seller(
                            id = '0', ), 
                        type = '0', 
                        address = allegro_api.models.address.Address(
                            street = '0', 
                            city = '0', 
                            zip_code = '0', 
                            state = '0', 
                            country_code = '0', 
                            coordinates = allegro_api.models.coordinates.Coordinates(
                                lat = 1.337, 
                                lon = 1.337, ), ), 
                        phone_number = '0', 
                        email = '0', 
                        open_hours = [
                            allegro_api.models.open_hour.OpenHour(
                                day_of_week = '0', 
                                from = '0', 
                                to = '0', )
                            ], 
                        service_time = '0', 
                        payments = [
                            allegro_api.models.payment.Payment(
                                method = '0', )
                            ], 
                        confirmation_type = '0', 
                        status = '0', 
                        created_at = '0', 
                        updated_at = '0', )
                    ]
            )
        else :
            return SearchResult(
        )

    def testSearchResult(self):
        """Test SearchResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from allegro_api.models.additional_email import AdditionalEmail
from allegro_api.models.additional_email_request import AdditionalEmailRequest
from allegro_api.models.additional_emails_response import AdditionalEmailsResponse
from allegro_api.models.additional_service_definition_request import AdditionalServiceDefinitionRequest
from allegro_api.models.additional_service_request import AdditionalServiceRequest
from allegro_api.models.additional_service_response import AdditionalServiceResponse
from allegro_api.models.additional_services_group import AdditionalServicesGroup
from allegro_api.models.additional_services_group_request import AdditionalServicesGroupRequest
from allegro_api.models.additional_services_group_response import AdditionalServicesGroupResponse
from allegro_api.models.additional_services_groups import AdditionalServicesGroups
from allegro_api.models.address import Address
from allegro_api.models.after_sales_services import AfterSalesServices
from allegro_api.models.answer import Answer
from allegro_api.models.application_time_policy import ApplicationTimePolicy
from allegro_api.models.attachment import Attachment
from allegro_api.models.attachment_declaration import AttachmentDeclaration
from allegro_api.models.attachment_file import AttachmentFile
from allegro_api.models.attachment_file_request import AttachmentFileRequest
from allegro_api.models.attachment_type import AttachmentType
from allegro_api.models.auction_details import AuctionDetails
from allegro_api.models.auth_error import AuthError
from allegro_api.models.available_constraint import AvailableConstraint
from allegro_api.models.average_rates import AverageRates
from allegro_api.models.badge import Badge
from allegro_api.models.badge_application import BadgeApplication
from allegro_api.models.badge_application_bargain_price import BadgeApplicationBargainPrice
from allegro_api.models.badge_application_campaign import BadgeApplicationCampaign
from allegro_api.models.badge_application_market_price import BadgeApplicationMarketPrice
from allegro_api.models.badge_application_offer import BadgeApplicationOffer
from allegro_api.models.badge_application_prices import BadgeApplicationPrices
from allegro_api.models.badge_application_process import BadgeApplicationProcess
from allegro_api.models.badge_application_purchase_constraints import BadgeApplicationPurchaseConstraints
from allegro_api.models.badge_application_purchase_constraints_limit import BadgeApplicationPurchaseConstraintsLimit
from allegro_api.models.badge_application_purchase_constraints_limit_per_user import BadgeApplicationPurchaseConstraintsLimitPerUser
from allegro_api.models.badge_application_rejection_reason import BadgeApplicationRejectionReason
from allegro_api.models.badge_application_rejection_reason_message import BadgeApplicationRejectionReasonMessage
from allegro_api.models.badge_application_request import BadgeApplicationRequest
from allegro_api.models.badge_applications import BadgeApplications
from allegro_api.models.badge_campaign import BadgeCampaign
from allegro_api.models.badge_process import BadgeProcess
from allegro_api.models.badge_publication_time_policy import BadgePublicationTimePolicy
from allegro_api.models.badges_list import BadgesList
from allegro_api.models.base_operation import BaseOperation
from allegro_api.models.basic_definition_response import BasicDefinitionResponse
from allegro_api.models.benefit import Benefit
from allegro_api.models.benefit_specification import BenefitSpecification
from allegro_api.models.bid_request import BidRequest
from allegro_api.models.black_list_paged_response import BlackListPagedResponse
from allegro_api.models.black_list_response import BlackListResponse
from allegro_api.models.blacklist_request import BlacklistRequest
from allegro_api.models.blacklist_user import BlacklistUser
from allegro_api.models.bundle_benefit_specification import BundleBenefitSpecification
from allegro_api.models.bundle_benefit_specification_all_of import BundleBenefitSpecificationAllOf
from allegro_api.models.buy_now_price import BuyNowPrice
from allegro_api.models.buyer_participant import BuyerParticipant
from allegro_api.models.buyer_participant_all_of import BuyerParticipantAllOf
from allegro_api.models.buyer_reference import BuyerReference
from allegro_api.models.campaign_refusal_reason import CampaignRefusalReason
from allegro_api.models.campaign_request_dto import CampaignRequestDto
from allegro_api.models.campaign_response_dto import CampaignResponseDto
from allegro_api.models.caption import Caption
from allegro_api.models.categories_dto import CategoriesDto
from allegro_api.models.category import Category
from allegro_api.models.category_dto import CategoryDto
from allegro_api.models.category_dto_parent import CategoryDtoParent
from allegro_api.models.category_options_dto import CategoryOptionsDto
from allegro_api.models.category_parameter import CategoryParameter
from allegro_api.models.category_parameter_list import CategoryParameterList
from allegro_api.models.category_parameter_options import CategoryParameterOptions
from allegro_api.models.category_product_parameter import CategoryProductParameter
from allegro_api.models.category_product_parameter_list import CategoryProductParameterList
from allegro_api.models.cells import Cells
from allegro_api.models.change_price import ChangePrice
from allegro_api.models.change_price_input import ChangePriceInput
from allegro_api.models.change_price_without_output import ChangePriceWithoutOutput
from allegro_api.models.checkout_form import CheckoutForm
from allegro_api.models.checkout_form_add_waybill_created import CheckoutFormAddWaybillCreated
from allegro_api.models.checkout_form_add_waybill_request import CheckoutFormAddWaybillRequest
from allegro_api.models.checkout_form_additional_service import CheckoutFormAdditionalService
from allegro_api.models.checkout_form_buyer_address_reference import CheckoutFormBuyerAddressReference
from allegro_api.models.checkout_form_buyer_reference import CheckoutFormBuyerReference
from allegro_api.models.checkout_form_delivery_address import CheckoutFormDeliveryAddress
from allegro_api.models.checkout_form_delivery_method import CheckoutFormDeliveryMethod
from allegro_api.models.checkout_form_delivery_pickup_point import CheckoutFormDeliveryPickupPoint
from allegro_api.models.checkout_form_delivery_pickup_point_address import CheckoutFormDeliveryPickupPointAddress
from allegro_api.models.checkout_form_delivery_reference import CheckoutFormDeliveryReference
from allegro_api.models.checkout_form_delivery_time import CheckoutFormDeliveryTime
from allegro_api.models.checkout_form_delivery_time_guaranteed import CheckoutFormDeliveryTimeGuaranteed
from allegro_api.models.checkout_form_discount import CheckoutFormDiscount
from allegro_api.models.checkout_form_fulfillment import CheckoutFormFulfillment
from allegro_api.models.checkout_form_fulfillment_shipment_summary import CheckoutFormFulfillmentShipmentSummary
from allegro_api.models.checkout_form_fulfillment_shipment_summary_line_items_sent import CheckoutFormFulfillmentShipmentSummaryLineItemsSent
from allegro_api.models.checkout_form_fulfillment_status import CheckoutFormFulfillmentStatus
from allegro_api.models.checkout_form_invoice_address import CheckoutFormInvoiceAddress
from allegro_api.models.checkout_form_invoice_address_company import CheckoutFormInvoiceAddressCompany
from allegro_api.models.checkout_form_invoice_address_natural_person import CheckoutFormInvoiceAddressNaturalPerson
from allegro_api.models.checkout_form_invoice_info import CheckoutFormInvoiceInfo
from allegro_api.models.checkout_form_line_item import CheckoutFormLineItem
from allegro_api.models.checkout_form_order_waybill_response import CheckoutFormOrderWaybillResponse
from allegro_api.models.checkout_form_payment_provider import CheckoutFormPaymentProvider
from allegro_api.models.checkout_form_payment_reference import CheckoutFormPaymentReference
from allegro_api.models.checkout_form_payment_type import CheckoutFormPaymentType
from allegro_api.models.checkout_form_reference import CheckoutFormReference
from allegro_api.models.checkout_form_status import CheckoutFormStatus
from allegro_api.models.checkout_form_summary import CheckoutFormSummary
from allegro_api.models.checkout_forms import CheckoutForms
from allegro_api.models.classified_extension import ClassifiedExtension
from allegro_api.models.classified_package import ClassifiedPackage
from allegro_api.models.classified_package_config import ClassifiedPackageConfig
from allegro_api.models.classified_package_configs import ClassifiedPackageConfigs
from allegro_api.models.classified_packages import ClassifiedPackages
from allegro_api.models.classified_promotion import ClassifiedPromotion
from allegro_api.models.classified_publication import ClassifiedPublication
from allegro_api.models.classified_response import ClassifiedResponse
from allegro_api.models.classifieds_packages import ClassifiedsPackages
from allegro_api.models.command_output import CommandOutput
from allegro_api.models.command_task import CommandTask
from allegro_api.models.commission_response import CommissionResponse
from allegro_api.models.company import Company
from allegro_api.models.compatibility_list import CompatibilityList
from allegro_api.models.compatibility_list_id_item import CompatibilityListIdItem
from allegro_api.models.compatibility_list_id_item_additional_info import CompatibilityListIdItemAdditionalInfo
from allegro_api.models.compatibility_list_id_item_all_of import CompatibilityListIdItemAllOf
from allegro_api.models.compatibility_list_item import CompatibilityListItem
from allegro_api.models.compatibility_list_item_product_based import CompatibilityListItemProductBased
from allegro_api.models.compatibility_list_manual import CompatibilityListManual
from allegro_api.models.compatibility_list_manual_all_of import CompatibilityListManualAllOf
from allegro_api.models.compatibility_list_product_based import CompatibilityListProductBased
from allegro_api.models.compatibility_list_product_based_all_of import CompatibilityListProductBasedAllOf
from allegro_api.models.compatibility_list_supported_categories_dto import CompatibilityListSupportedCategoriesDto
from allegro_api.models.compatibility_list_supported_categories_dto_supported_categories import CompatibilityListSupportedCategoriesDtoSupportedCategories
from allegro_api.models.compatibility_list_supported_categories_dto_validation_rules import CompatibilityListSupportedCategoriesDtoValidationRules
from allegro_api.models.compatibility_list_text_item import CompatibilityListTextItem
from allegro_api.models.compatibility_list_text_item_all_of import CompatibilityListTextItemAllOf
from allegro_api.models.compatible_product_dto import CompatibleProductDto
from allegro_api.models.compatible_product_dto_attributes import CompatibleProductDtoAttributes
from allegro_api.models.compatible_product_dto_group import CompatibleProductDtoGroup
from allegro_api.models.compatible_products_groups_dto import CompatibleProductsGroupsDto
from allegro_api.models.compatible_products_groups_dto_groups import CompatibleProductsGroupsDtoGroups
from allegro_api.models.compatible_products_list_dto import CompatibleProductsListDto
from allegro_api.models.configuration import Configuration
from allegro_api.models.constraint_criteria import ConstraintCriteria
from allegro_api.models.contact_request import ContactRequest
from allegro_api.models.contact_response import ContactResponse
from allegro_api.models.contact_response_list import ContactResponseList
from allegro_api.models.contribution_operation import ContributionOperation
from allegro_api.models.contribution_operation_all_of import ContributionOperationAllOf
from allegro_api.models.coordinates import Coordinates
from allegro_api.models.correction_operation import CorrectionOperation
from allegro_api.models.correction_operation_all_of import CorrectionOperationAllOf
from allegro_api.models.current_price import CurrentPrice
from allegro_api.models.deduction import Deduction
from allegro_api.models.deduction_charge_operation import DeductionChargeOperation
from allegro_api.models.deduction_charge_operation_all_of import DeductionChargeOperationAllOf
from allegro_api.models.deduction_increase_operation import DeductionIncreaseOperation
from allegro_api.models.deduction_increase_operation_all_of import DeductionIncreaseOperationAllOf
from allegro_api.models.definitions_response import DefinitionsResponse
from allegro_api.models.delivery import Delivery
from allegro_api.models.delivery_settings_dto import DeliverySettingsDto
from allegro_api.models.delivery_settings_dto_custom_cost import DeliverySettingsDtoCustomCost
from allegro_api.models.delivery_settings_dto_free_delivery import DeliverySettingsDtoFreeDelivery
from allegro_api.models.delivery_settings_dto_join_policy import DeliverySettingsDtoJoinPolicy
from allegro_api.models.describes_listing_fee import DescribesListingFee
from allegro_api.models.describes_success_commission_fee import DescribesSuccessCommissionFee
from allegro_api.models.description_section import DescriptionSection
from allegro_api.models.description_section_item import DescriptionSectionItem
from allegro_api.models.description_section_item_image import DescriptionSectionItemImage
from allegro_api.models.description_section_item_image_all_of import DescriptionSectionItemImageAllOf
from allegro_api.models.description_section_item_text import DescriptionSectionItemText
from allegro_api.models.description_section_item_text_all_of import DescriptionSectionItemTextAllOf
from allegro_api.models.dictionary_category_parameter import DictionaryCategoryParameter
from allegro_api.models.dictionary_category_product_parameter import DictionaryCategoryProductParameter
from allegro_api.models.dictionary_category_product_parameter_all_of import DictionaryCategoryProductParameterAllOf
from allegro_api.models.dictionary_category_product_parameter_all_of_dictionary import DictionaryCategoryProductParameterAllOfDictionary
from allegro_api.models.dictionary_category_product_parameter_all_of_restrictions import DictionaryCategoryProductParameterAllOfRestrictions
from allegro_api.models.dispute import Dispute
from allegro_api.models.dispute_attachment import DisputeAttachment
from allegro_api.models.dispute_attachment_id import DisputeAttachmentId
from allegro_api.models.dispute_author import DisputeAuthor
from allegro_api.models.dispute_author_role import DisputeAuthorRole
from allegro_api.models.dispute_checkout_form import DisputeCheckoutForm
from allegro_api.models.dispute_first_message import DisputeFirstMessage
from allegro_api.models.dispute_list_response import DisputeListResponse
from allegro_api.models.dispute_message import DisputeMessage
from allegro_api.models.dispute_message_author import DisputeMessageAuthor
from allegro_api.models.dispute_message_list import DisputeMessageList
from allegro_api.models.dispute_user import DisputeUser
from allegro_api.models.email_request import EmailRequest
from allegro_api.models.email_response import EmailResponse
from allegro_api.models.error import Error
from allegro_api.models.errors_holder import ErrorsHolder
from allegro_api.models.external_id import ExternalId
from allegro_api.models.fee import Fee
from allegro_api.models.fee_preview_response import FeePreviewResponse
from allegro_api.models.float_category_parameter import FloatCategoryParameter
from allegro_api.models.float_category_product_parameter import FloatCategoryProductParameter
from allegro_api.models.float_category_product_parameter_all_of import FloatCategoryProductParameterAllOf
from allegro_api.models.float_category_product_parameter_all_of_restrictions import FloatCategoryProductParameterAllOfRestrictions
from allegro_api.models.full_definition_response import FullDefinitionResponse
from allegro_api.models.general_report import GeneralReport
from allegro_api.models.get_badge_campaigns_list import GetBadgeCampaignsList
from allegro_api.models.get_sale_products_response import GetSaleProductsResponse
from allegro_api.models.get_sale_products_response_next_page import GetSaleProductsResponseNextPage
from allegro_api.models.header import Header
from allegro_api.models.image_url import ImageUrl
from allegro_api.models.implied_warranties_list_implied_warranty_basic import ImpliedWarrantiesListImpliedWarrantyBasic
from allegro_api.models.implied_warranty import ImpliedWarranty
from allegro_api.models.implied_warranty_basic import ImpliedWarrantyBasic
from allegro_api.models.initialize_refund import InitializeRefund
from allegro_api.models.initialize_refund_additional_services import InitializeRefundAdditionalServices
from allegro_api.models.initialize_refund_delivery import InitializeRefundDelivery
from allegro_api.models.initialize_refund_overpaid import InitializeRefundOverpaid
from allegro_api.models.inline_response200 import InlineResponse200
from allegro_api.models.inline_response2001 import InlineResponse2001
from allegro_api.models.inline_response2001_delivery_methods import InlineResponse2001DeliveryMethods
from allegro_api.models.inline_response2001_shipping_rates_constraints import InlineResponse2001ShippingRatesConstraints
from allegro_api.models.inline_response2001_shipping_rates_constraints_first_item_rate import InlineResponse2001ShippingRatesConstraintsFirstItemRate
from allegro_api.models.inline_response2001_shipping_rates_constraints_max_quantity_per_package import InlineResponse2001ShippingRatesConstraintsMaxQuantityPerPackage
from allegro_api.models.inline_response2001_shipping_rates_constraints_next_item_rate import InlineResponse2001ShippingRatesConstraintsNextItemRate
from allegro_api.models.inline_response2001_shipping_rates_constraints_shipping_time import InlineResponse2001ShippingRatesConstraintsShippingTime
from allegro_api.models.inline_response2001_shipping_rates_constraints_shipping_time_default import InlineResponse2001ShippingRatesConstraintsShippingTimeDefault
from allegro_api.models.inline_response200_shipping_rates import InlineResponse200ShippingRates
from allegro_api.models.integer_category_parameter import IntegerCategoryParameter
from allegro_api.models.integer_category_product_parameter import IntegerCategoryProductParameter
from allegro_api.models.integer_category_product_parameter_all_of import IntegerCategoryProductParameterAllOf
from allegro_api.models.integer_category_product_parameter_all_of_restrictions import IntegerCategoryProductParameterAllOfRestrictions
from allegro_api.models.just_id import JustId
from allegro_api.models.latest_order_event import LatestOrderEvent
from allegro_api.models.line_item_id_mappings import LineItemIdMappings
from allegro_api.models.line_item_id_mappings_mappings import LineItemIdMappingsMappings
from allegro_api.models.listing_category import ListingCategory
from allegro_api.models.listing_category_with_count import ListingCategoryWithCount
from allegro_api.models.listing_offer import ListingOffer
from allegro_api.models.listing_response import ListingResponse
from allegro_api.models.listing_response_categories import ListingResponseCategories
from allegro_api.models.listing_response_filters import ListingResponseFilters
from allegro_api.models.listing_response_filters_values import ListingResponseFiltersValues
from allegro_api.models.listing_response_offers import ListingResponseOffers
from allegro_api.models.listing_response_search_meta import ListingResponseSearchMeta
from allegro_api.models.listing_response_sort import ListingResponseSort
from allegro_api.models.location import Location
from allegro_api.models.max_price import MaxPrice
from allegro_api.models.me_response import MeResponse
from allegro_api.models.message_author_role import MessageAuthorRole
from allegro_api.models.message_request import MessageRequest
from allegro_api.models.minimal_price import MinimalPrice
from allegro_api.models.modification import Modification
from allegro_api.models.modification_delivery import ModificationDelivery
from allegro_api.models.modification_payments import ModificationPayments
from allegro_api.models.modification_promotion import ModificationPromotion
from allegro_api.models.modification_publication import ModificationPublication
from allegro_api.models.modification_size_table import ModificationSizeTable
from allegro_api.models.multi_pack_benefit_specification import MultiPackBenefitSpecification
from allegro_api.models.multi_pack_benefit_specification_all_of import MultiPackBenefitSpecificationAllOf
from allegro_api.models.multi_pack_benefit_specification_all_of_configuration import MultiPackBenefitSpecificationAllOfConfiguration
from allegro_api.models.multi_pack_benefit_specification_all_of_trigger import MultiPackBenefitSpecificationAllOfTrigger
from allegro_api.models.my_bid_response import MyBidResponse
from allegro_api.models.offer import Offer
from allegro_api.models.offer_activated_event import OfferActivatedEvent
from allegro_api.models.offer_activated_event_all_of import OfferActivatedEventAllOf
from allegro_api.models.offer_additional_services import OfferAdditionalServices
from allegro_api.models.offer_archived_event import OfferArchivedEvent
from allegro_api.models.offer_archived_event_all_of import OfferArchivedEventAllOf
from allegro_api.models.offer_attachment import OfferAttachment
from allegro_api.models.offer_attachment_request import OfferAttachmentRequest
from allegro_api.models.offer_badge_campaign import OfferBadgeCampaign
from allegro_api.models.offer_bid_canceled_event import OfferBidCanceledEvent
from allegro_api.models.offer_bid_canceled_event_all_of import OfferBidCanceledEventAllOf
from allegro_api.models.offer_bid_placed_event import OfferBidPlacedEvent
from allegro_api.models.offer_bid_placed_event_all_of import OfferBidPlacedEventAllOf
from allegro_api.models.offer_category import OfferCategory
from allegro_api.models.offer_change_command import OfferChangeCommand
from allegro_api.models.offer_changed_event import OfferChangedEvent
from allegro_api.models.offer_changed_event_all_of import OfferChangedEventAllOf
from allegro_api.models.offer_criterium import OfferCriterium
from allegro_api.models.offer_delivery import OfferDelivery
from allegro_api.models.offer_ended_event import OfferEndedEvent
from allegro_api.models.offer_ended_event_all_of import OfferEndedEventAllOf
from allegro_api.models.offer_event_base_offer import OfferEventBaseOffer
from allegro_api.models.offer_event_ended_offer import OfferEventEndedOffer
from allegro_api.models.offer_event_ended_offer_all_of import OfferEventEndedOfferAllOf
from allegro_api.models.offer_event_ended_offer_all_of_publication import OfferEventEndedOfferAllOfPublication
from allegro_api.models.offer_fixed_price import OfferFixedPrice
from allegro_api.models.offer_id import OfferId
from allegro_api.models.offer_image_link_upload_request import OfferImageLinkUploadRequest
from allegro_api.models.offer_image_upload_response import OfferImageUploadResponse
from allegro_api.models.offer_images import OfferImages
from allegro_api.models.offer_listing_dto import OfferListingDto
from allegro_api.models.offer_listing_dto_image import OfferListingDtoImage
from allegro_api.models.offer_listing_dto_v1_delivery import OfferListingDtoV1Delivery
from allegro_api.models.offer_listing_dto_v1_publication import OfferListingDtoV1Publication
from allegro_api.models.offer_listing_dto_v1_sale_info import OfferListingDtoV1SaleInfo
from allegro_api.models.offer_listing_dto_v1_stats import OfferListingDtoV1Stats
from allegro_api.models.offer_listing_dto_v1_stock import OfferListingDtoV1Stock
from allegro_api.models.offer_lowest_price import OfferLowestPrice
from allegro_api.models.offer_price import OfferPrice
from allegro_api.models.offer_price_change_command import OfferPriceChangeCommand
from allegro_api.models.offer_price_changed_event import OfferPriceChangedEvent
from allegro_api.models.offer_price_changed_event_all_of import OfferPriceChangedEventAllOf
from allegro_api.models.offer_promotion import OfferPromotion
from allegro_api.models.offer_publication import OfferPublication
from allegro_api.models.offer_quantity_change_command import OfferQuantityChangeCommand
from allegro_api.models.offer_quote_dto import OfferQuoteDto
from allegro_api.models.offer_quotes_dto import OfferQuotesDto
from allegro_api.models.offer_rating import OfferRating
from allegro_api.models.offer_rating_score_distribution import OfferRatingScoreDistribution
from allegro_api.models.offer_rating_size_feedback import OfferRatingSizeFeedback
from allegro_api.models.offer_reference import OfferReference
from allegro_api.models.offer_requirements import OfferRequirements
from allegro_api.models.offer_seller import OfferSeller
from allegro_api.models.offer_selling_mode import OfferSellingMode
from allegro_api.models.offer_shipping_rates import OfferShippingRates
from allegro_api.models.offer_status import OfferStatus
from allegro_api.models.offer_stock import OfferStock
from allegro_api.models.offer_stock_changed_event import OfferStockChangedEvent
from allegro_api.models.offer_stock_changed_event_all_of import OfferStockChangedEventAllOf
from allegro_api.models.offer_vendor import OfferVendor
from allegro_api.models.offers_search_result_dto import OffersSearchResultDto
from allegro_api.models.open_hour import OpenHour
from allegro_api.models.operation_participant_address import OperationParticipantAddress
from allegro_api.models.operation_payment import OperationPayment
from allegro_api.models.operation_value import OperationValue
from allegro_api.models.order import Order
from allegro_api.models.order_event import OrderEvent
from allegro_api.models.order_event_data import OrderEventData
from allegro_api.models.order_event_stats import OrderEventStats
from allegro_api.models.order_event_type import OrderEventType
from allegro_api.models.order_events_list import OrderEventsList
from allegro_api.models.order_line_item import OrderLineItem
from allegro_api.models.parameter import Parameter
from allegro_api.models.parameter_range_value import ParameterRangeValue
from allegro_api.models.parameters_for_preview_price import ParametersForPreviewPrice
from allegro_api.models.participant import Participant
from allegro_api.models.payment import Payment
from allegro_api.models.payment_id_mapping import PaymentIdMapping
from allegro_api.models.payment_operations import PaymentOperations
from allegro_api.models.payments import Payments
from allegro_api.models.payments_surcharge import PaymentsSurcharge
from allegro_api.models.payout import Payout
from allegro_api.models.payout_operation import PayoutOperation
from allegro_api.models.payout_operation_all_of import PayoutOperationAllOf
from allegro_api.models.payout_operation_cancel import PayoutOperationCancel
from allegro_api.models.payout_operation_cancel_all_of import PayoutOperationCancelAllOf
from allegro_api.models.phones_request import PhonesRequest
from allegro_api.models.phones_response import PhonesResponse
from allegro_api.models.pos import Pos
from allegro_api.models.price import Price
from allegro_api.models.price_modification import PriceModification
from allegro_api.models.price_modification_fixed_price import PriceModificationFixedPrice
from allegro_api.models.price_modification_fixed_price_all_of import PriceModificationFixedPriceAllOf
from allegro_api.models.price_modification_fixed_price_holder import PriceModificationFixedPriceHolder
from allegro_api.models.price_modification_percentage_change_decrease import PriceModificationPercentageChangeDecrease
from allegro_api.models.price_modification_percentage_change_decrease_all_of import PriceModificationPercentageChangeDecreaseAllOf
from allegro_api.models.price_modification_percentage_change_increase import PriceModificationPercentageChangeIncrease
from allegro_api.models.price_modification_percentage_change_increase_all_of import PriceModificationPercentageChangeIncreaseAllOf
from allegro_api.models.price_modification_value_change_decrease import PriceModificationValueChangeDecrease
from allegro_api.models.price_modification_value_change_decrease_all_of import PriceModificationValueChangeDecreaseAllOf
from allegro_api.models.price_modification_value_change_holder import PriceModificationValueChangeHolder
from allegro_api.models.price_modification_value_change_increase import PriceModificationValueChangeIncrease
from allegro_api.models.price_modification_value_change_increase_all_of import PriceModificationValueChangeIncreaseAllOf
from allegro_api.models.processing_status import ProcessingStatus
from allegro_api.models.product_parameter import ProductParameter
from allegro_api.models.product_parameter_options import ProductParameterOptions
from allegro_api.models.products_category_path import ProductsCategoryPath
from allegro_api.models.products_category_subcategories import ProductsCategorySubcategories
from allegro_api.models.promotion import Promotion
from allegro_api.models.promotion_campaign_request_dto import PromotionCampaignRequestDto
from allegro_api.models.promotion_campaign_response_dto import PromotionCampaignResponseDto
from allegro_api.models.promotion_campaigns_response_dto import PromotionCampaignsResponseDto
from allegro_api.models.promotion_request_dto import PromotionRequestDto
from allegro_api.models.promotion_response_dto import PromotionResponseDto
from allegro_api.models.propose_sale_product_request import ProposeSaleProductRequest
from allegro_api.models.public_offer_preview_request import PublicOfferPreviewRequest
from allegro_api.models.public_table_dto import PublicTableDto
from allegro_api.models.public_table_image_dto import PublicTableImageDto
from allegro_api.models.public_tables_dto import PublicTablesDto
from allegro_api.models.publication import Publication
from allegro_api.models.publication_change_command_dto import PublicationChangeCommandDto
from allegro_api.models.publication_modification import PublicationModification
from allegro_api.models.publication_time_policy import PublicationTimePolicy
from allegro_api.models.quantity_modification import QuantityModification
from allegro_api.models.quote_response import QuoteResponse
from allegro_api.models.rates import Rates
from allegro_api.models.reference import Reference
from allegro_api.models.refund_additional_services_value import RefundAdditionalServicesValue
from allegro_api.models.refund_cancel_operation import RefundCancelOperation
from allegro_api.models.refund_cancel_operation_all_of import RefundCancelOperationAllOf
from allegro_api.models.refund_charge_operation import RefundChargeOperation
from allegro_api.models.refund_charge_operation_all_of import RefundChargeOperationAllOf
from allegro_api.models.refund_delivery_value import RefundDeliveryValue
from allegro_api.models.refund_details import RefundDetails
from allegro_api.models.refund_increase_operation import RefundIncreaseOperation
from allegro_api.models.refund_increase_operation_all_of import RefundIncreaseOperationAllOf
from allegro_api.models.refund_line_item import RefundLineItem
from allegro_api.models.refund_line_item_value import RefundLineItemValue
from allegro_api.models.refund_overpaid_value import RefundOverpaidValue
from allegro_api.models.refund_payment import RefundPayment
from allegro_api.models.refund_surcharge_value import RefundSurchargeValue
from allegro_api.models.refund_total_value import RefundTotalValue
from allegro_api.models.refusal_message import RefusalMessage
from allegro_api.models.removal import Removal
from allegro_api.models.removal_request import RemovalRequest
from allegro_api.models.return_policies_list_return_policy_basic import ReturnPoliciesListReturnPolicyBasic
from allegro_api.models.return_policy import ReturnPolicy
from allegro_api.models.return_policy_basic import ReturnPolicyBasic
from allegro_api.models.sale_product_compatibility_list import SaleProductCompatibilityList
from allegro_api.models.sale_product_dto import SaleProductDto
from allegro_api.models.sale_product_response_categories_dto import SaleProductResponseCategoriesDto
from allegro_api.models.sale_product_response_dto import SaleProductResponseDto
from allegro_api.models.search_result import SearchResult
from allegro_api.models.seller import Seller
from allegro_api.models.seller_create_rebate_request_dto import SellerCreateRebateRequestDto
from allegro_api.models.seller_offer_base_event import SellerOfferBaseEvent
from allegro_api.models.seller_offer_events_response import SellerOfferEventsResponse
from allegro_api.models.seller_participant import SellerParticipant
from allegro_api.models.seller_participant_all_of import SellerParticipantAllOf
from allegro_api.models.seller_rebate_dto import SellerRebateDto
from allegro_api.models.seller_rebate_offer_criterion import SellerRebateOfferCriterion
from allegro_api.models.seller_rebate_offer_criterion_offers import SellerRebateOfferCriterionOffers
from allegro_api.models.seller_rebates_dto import SellerRebatesDto
from allegro_api.models.seller_reference import SellerReference
from allegro_api.models.selling_mode import SellingMode
from allegro_api.models.selling_mode_format import SellingModeFormat
from allegro_api.models.shipping_rate import ShippingRate
from allegro_api.models.shipping_rate_delivery_method import ShippingRateDeliveryMethod
from allegro_api.models.shipping_rate_first_item_rate import ShippingRateFirstItemRate
from allegro_api.models.shipping_rate_next_item_rate import ShippingRateNextItemRate
from allegro_api.models.shipping_rate_shipping_time import ShippingRateShippingTime
from allegro_api.models.shipping_rates import ShippingRates
from allegro_api.models.shipping_rates_set import ShippingRatesSet
from allegro_api.models.single_promotion_campaign_response_dto import SinglePromotionCampaignResponseDto
from allegro_api.models.standardized_description import StandardizedDescription
from allegro_api.models.starting_price import StartingPrice
from allegro_api.models.stock import Stock
from allegro_api.models.string_category_parameter import StringCategoryParameter
from allegro_api.models.string_category_product_parameter import StringCategoryProductParameter
from allegro_api.models.string_category_product_parameter_all_of import StringCategoryProductParameterAllOf
from allegro_api.models.string_category_product_parameter_all_of_restrictions import StringCategoryProductParameterAllOfRestrictions
from allegro_api.models.subject import Subject
from allegro_api.models.surcharge import Surcharge
from allegro_api.models.surcharge_operation import SurchargeOperation
from allegro_api.models.surcharge_operation_all_of import SurchargeOperationAllOf
from allegro_api.models.tag_id import TagId
from allegro_api.models.tag_ids_request import TagIdsRequest
from allegro_api.models.tag_list_response import TagListResponse
from allegro_api.models.tag_request import TagRequest
from allegro_api.models.tag_response import TagResponse
from allegro_api.models.task_count import TaskCount
from allegro_api.models.task_report import TaskReport
from allegro_api.models.tecdoc_specification import TecdocSpecification
from allegro_api.models.tecdoc_specification_item import TecdocSpecificationItem
from allegro_api.models.user import User
from allegro_api.models.user_campaign_eligibility import UserCampaignEligibility
from allegro_api.models.user_rating import UserRating
from allegro_api.models.user_rating_answer_request import UserRatingAnswerRequest
from allegro_api.models.user_rating_list_response import UserRatingListResponse
from allegro_api.models.user_rating_removal_request import UserRatingRemovalRequest
from allegro_api.models.user_rating_removal_request_request import UserRatingRemovalRequestRequest
from allegro_api.models.user_rating_summary_response import UserRatingSummaryResponse
from allegro_api.models.user_rating_summary_response_not_recommended import UserRatingSummaryResponseNotRecommended
from allegro_api.models.user_rating_summary_response_recommended import UserRatingSummaryResponseRecommended
from allegro_api.models.validation import Validation
from allegro_api.models.validation_error import ValidationError
from allegro_api.models.variant_set import VariantSet
from allegro_api.models.variant_set_offer import VariantSetOffer
from allegro_api.models.variant_set_parameter import VariantSetParameter
from allegro_api.models.variant_sets import VariantSets
from allegro_api.models.variant_sets_variant_set import VariantSetsVariantSet
from allegro_api.models.visibility_time_policy import VisibilityTimePolicy
from allegro_api.models.wallet import Wallet
from allegro_api.models.wallet_balance import WalletBalance
from allegro_api.models.warranties_list_warranty_basic import WarrantiesListWarrantyBasic
from allegro_api.models.warranty import Warranty
from allegro_api.models.warranty_basic import WarrantyBasic
from allegro_api.models.wrapper_type_for_preview_conditions import WrapperTypeForPreviewConditions
from allegro_api.models.wraps_listing_and_commissions_fees import WrapsListingAndCommissionsFees



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class DisputesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_message_to_dispute_using_post(self, dispute_id, message_request, **kwargs):  # noqa: E501
        """Add a message to a dispute  # noqa: E501

        Use this resource to post a message in certain dispute. At least one of fields: 'text', 'attachment' has to be present. <a href=\"../../news/2018-09-18-dyskusje/#PostMessage\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_message_to_dispute_using_post(dispute_id, message_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str dispute_id: Dispute identifier. (required)
        :param MessageRequest message_request: Message request (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DisputeMessage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_message_to_dispute_using_post_with_http_info(dispute_id, message_request, **kwargs)  # noqa: E501

    def add_message_to_dispute_using_post_with_http_info(self, dispute_id, message_request, **kwargs):  # noqa: E501
        """Add a message to a dispute  # noqa: E501

        Use this resource to post a message in certain dispute. At least one of fields: 'text', 'attachment' has to be present. <a href=\"../../news/2018-09-18-dyskusje/#PostMessage\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_message_to_dispute_using_post_with_http_info(dispute_id, message_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str dispute_id: Dispute identifier. (required)
        :param MessageRequest message_request: Message request (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DisputeMessage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['dispute_id', 'message_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_message_to_dispute_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'dispute_id' is set
        if self.api_client.client_side_validation and ('dispute_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['dispute_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `dispute_id` when calling `add_message_to_dispute_using_post`")  # noqa: E501
        # verify the required parameter 'message_request' is set
        if self.api_client.client_side_validation and ('message_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['message_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message_request` when calling `add_message_to_dispute_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'dispute_id' in local_var_params:
            path_params['disputeId'] = local_var_params['dispute_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'message_request' in local_var_params:
            body_params = local_var_params['message_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/disputes/{disputeId}/messages', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DisputeMessage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_an_attachment_using_post(self, attachment_declaration, **kwargs):  # noqa: E501
        """Create an attachment declaration  # noqa: E501

        Use this resource to post an attachment declaration. <a href=\"../../news/2018-09-18-dyskusje/#PostAttach\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_an_attachment_using_post(attachment_declaration, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AttachmentDeclaration attachment_declaration: A detailed declaration of a file to be uploaded (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DisputeAttachmentId
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_an_attachment_using_post_with_http_info(attachment_declaration, **kwargs)  # noqa: E501

    def create_an_attachment_using_post_with_http_info(self, attachment_declaration, **kwargs):  # noqa: E501
        """Create an attachment declaration  # noqa: E501

        Use this resource to post an attachment declaration. <a href=\"../../news/2018-09-18-dyskusje/#PostAttach\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_an_attachment_using_post_with_http_info(attachment_declaration, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AttachmentDeclaration attachment_declaration: A detailed declaration of a file to be uploaded (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DisputeAttachmentId, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['attachment_declaration']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_an_attachment_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attachment_declaration' is set
        if self.api_client.client_side_validation and ('attachment_declaration' not in local_var_params or  # noqa: E501
                                                        local_var_params['attachment_declaration'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attachment_declaration` when calling `create_an_attachment_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'attachment_declaration' in local_var_params:
            body_params = local_var_params['attachment_declaration']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/dispute-attachments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DisputeAttachmentId',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment_using_get(self, attachment_id, **kwargs):  # noqa: E501
        """Get an attachment  # noqa: E501

        Use this resource to get an attachment. <a href=\"../../news/2018-09-18-dyskusje/#GetAttach\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_using_get(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: Attachment identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_attachment_using_get_with_http_info(attachment_id, **kwargs)  # noqa: E501

    def get_attachment_using_get_with_http_info(self, attachment_id, **kwargs):  # noqa: E501
        """Get an attachment  # noqa: E501

        Use this resource to get an attachment. <a href=\"../../news/2018-09-18-dyskusje/#GetAttach\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_using_get_with_http_info(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: Attachment identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['attachment_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attachment_id' is set
        if self.api_client.client_side_validation and ('attachment_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attachment_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attachment_id` when calling `get_attachment_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attachment_id' in local_var_params:
            path_params['attachmentId'] = local_var_params['attachment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/dispute-attachments/{attachmentId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_dispute_using_get(self, dispute_id, **kwargs):  # noqa: E501
        """Get a single dispute  # noqa: E501

        Use this resource to get a single dispute. <a href=\"../../news/2018-09-18-dyskusje/#GetOne\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dispute_using_get(dispute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str dispute_id: Dispute identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Dispute
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_dispute_using_get_with_http_info(dispute_id, **kwargs)  # noqa: E501

    def get_dispute_using_get_with_http_info(self, dispute_id, **kwargs):  # noqa: E501
        """Get a single dispute  # noqa: E501

        Use this resource to get a single dispute. <a href=\"../../news/2018-09-18-dyskusje/#GetOne\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_dispute_using_get_with_http_info(dispute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str dispute_id: Dispute identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Dispute, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['dispute_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dispute_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'dispute_id' is set
        if self.api_client.client_side_validation and ('dispute_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['dispute_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `dispute_id` when calling `get_dispute_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'dispute_id' in local_var_params:
            path_params['disputeId'] = local_var_params['dispute_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/disputes/{disputeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Dispute',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_list_of_disputes_using_get(self, **kwargs):  # noqa: E501
        """Get the user's disputes  # noqa: E501

        Use this resource to get the list of your disputes. <a href=\"../../news/2018-09-18-dyskusje/#GetAll\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_of_disputes_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str checkout_form_id: Checkout form identifier.
        :param int limit: The maximum number of disputes in a response.
        :param int offset: Index of first returned dispute.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DisputeListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_list_of_disputes_using_get_with_http_info(**kwargs)  # noqa: E501

    def get_list_of_disputes_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get the user's disputes  # noqa: E501

        Use this resource to get the list of your disputes. <a href=\"../../news/2018-09-18-dyskusje/#GetAll\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_of_disputes_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str checkout_form_id: Checkout form identifier.
        :param int limit: The maximum number of disputes in a response.
        :param int offset: Index of first returned dispute.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DisputeListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['checkout_form_id', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_list_of_disputes_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_list_of_disputes_using_get`, must be a value less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_list_of_disputes_using_get`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_list_of_disputes_using_get`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'checkout_form_id' in local_var_params and local_var_params['checkout_form_id'] is not None:  # noqa: E501
            query_params.append(('checkoutForm.id', local_var_params['checkout_form_id']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/disputes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DisputeListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_messages_from_dispute_using_get(self, dispute_id, **kwargs):  # noqa: E501
        """Get the messages within a dispute  # noqa: E501

        Use this resource to get the list of messages within dispute. <a href=\"../../news/2018-09-18-dyskusje/#GetMessage\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_messages_from_dispute_using_get(dispute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str dispute_id: Dispute identifier. (required)
        :param int limit: The maximum number of messages within dispute returned in a response.
        :param int offset: Index of first returned message within dispute.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: DisputeMessageList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_messages_from_dispute_using_get_with_http_info(dispute_id, **kwargs)  # noqa: E501

    def get_messages_from_dispute_using_get_with_http_info(self, dispute_id, **kwargs):  # noqa: E501
        """Get the messages within a dispute  # noqa: E501

        Use this resource to get the list of messages within dispute. <a href=\"../../news/2018-09-18-dyskusje/#GetMessage\" target=\"_blank\">Read more</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_messages_from_dispute_using_get_with_http_info(dispute_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str dispute_id: Dispute identifier. (required)
        :param int limit: The maximum number of messages within dispute returned in a response.
        :param int offset: Index of first returned message within dispute.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(DisputeMessageList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['dispute_id', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_messages_from_dispute_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'dispute_id' is set
        if self.api_client.client_side_validation and ('dispute_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['dispute_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `dispute_id` when calling `get_messages_from_dispute_using_get`")  # noqa: E501

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 100:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_messages_from_dispute_using_get`, must be a value less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `get_messages_from_dispute_using_get`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `get_messages_from_dispute_using_get`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'dispute_id' in local_var_params:
            path_params['disputeId'] = local_var_params['dispute_id']  # noqa: E501

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/disputes/{disputeId}/messages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DisputeMessageList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_dispute_attachment_using_put(self, attachment_id, body, **kwargs):  # noqa: E501
        """Upload a dispute message attachment  # noqa: E501

        Upload a dispute message attachment. This operation should be used after creating an attachment declaration with *POST /sale/dispute-attachments* **Important!** You can find the URL address to upload the file to our server in the *Location* response header of *POST /sale/dispute-attachments*. The URL is unique and one-time. As its format may change in time, you should always use the address from the header. Do not compose the address on your own.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_dispute_attachment_using_put(attachment_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: Attachment identifier. (required)
        :param file body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upload_dispute_attachment_using_put_with_http_info(attachment_id, body, **kwargs)  # noqa: E501

    def upload_dispute_attachment_using_put_with_http_info(self, attachment_id, body, **kwargs):  # noqa: E501
        """Upload a dispute message attachment  # noqa: E501

        Upload a dispute message attachment. This operation should be used after creating an attachment declaration with *POST /sale/dispute-attachments* **Important!** You can find the URL address to upload the file to our server in the *Location* response header of *POST /sale/dispute-attachments*. The URL is unique and one-time. As its format may change in time, you should always use the address from the header. Do not compose the address on your own.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_dispute_attachment_using_put_with_http_info(attachment_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: Attachment identifier. (required)
        :param file body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_hosts = ['https://upload.{environment}']  # noqa: E501
        local_var_host = local_var_hosts[0]
        if kwargs.get('_host_index'):
            if int(kwags.get('_host_index')) < 0 or int(kawgs.get('_host_index')) >= len(local_var_hosts):
                raise ApiValueError("Invalid host index. Must be 0 <= index < %s" % len(local_var_host))
            local_var_host = local_var_hosts[int(kwargs.get('_host_index'))]
        local_var_params = locals()

        all_params = ['attachment_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params and key != "_host_index":
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_dispute_attachment_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attachment_id' is set
        if self.api_client.client_side_validation and ('attachment_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attachment_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attachment_id` when calling `upload_dispute_attachment_using_put`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `upload_dispute_attachment_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attachment_id' in local_var_params:
            path_params['attachmentId'] = local_var_params['attachment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['image/png', 'image/gif', 'image/bmp', 'image/tiff', 'image/jpeg', 'application/pdf'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/dispute-attachments/{attachmentId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            _host=local_var_host,
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.offer_listing_dto import OfferListingDto  # noqa: E501
from allegro_api.rest import ApiException

class TestOfferListingDto(unittest.TestCase):
    """OfferListingDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OfferListingDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.offer_listing_dto.OfferListingDto()  # noqa: E501
        if include_optional :
            return OfferListingDto(
                id = '2865624934', 
                name = 'Buty damskie adidas', 
                category = allegro_api.models.offer_category.OfferCategory(
                    id = '257929', ), 
                primary_image = allegro_api.models.offer_listing_dto_image.OfferListingDtoImage(
                    url = 'https://a.allegroimg.com/original/05a2af/929c6dae4fb8721a8539582eb421', ), 
                selling_mode = allegro_api.models.selling_mode.SellingMode(
                    format = 'BUY_NOW', 
                    price = null, 
                    minimal_price = null, 
                    starting_price = null, ), 
                sale_info = allegro_api.models.offer_listing_dto_v1_sale_info.OfferListingDtoV1SaleInfo(
                    current_price = null, 
                    bidders_count = 4, ), 
                stock = allegro_api.models.offer_listing_dto_v1_stock.OfferListingDtoV1Stock(
                    available = 23, 
                    sold = 3, ), 
                stats = allegro_api.models.offer_listing_dto_v1_stats.OfferListingDtoV1Stats(
                    watchers_count = 99, 
                    visits_count = 56, ), 
                publication = allegro_api.models.offer_listing_dto_v1_publication.OfferListingDtoV1Publication(
                    status = 'INACTIVE', 
                    starting_at = '2019-05-29T12:00:00Z', 
                    started_at = '2019-05-29T12:00:00Z', 
                    ending_at = '2019-06-30T12:00:00Z', 
                    ended_at = '2019-06-30T12:10:00Z', ), 
                after_sales_services = allegro_api.models.after_sales_services.AfterSalesServices(
                    implied_warranty = allegro_api.models.implied_warranty.ImpliedWarranty(
                        id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                    return_policy = allegro_api.models.return_policy.ReturnPolicy(
                        id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                    warranty = allegro_api.models.warranty.Warranty(
                        id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), ), 
                additional_services = allegro_api.models.offer_additional_services.OfferAdditionalServices(
                    id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                external = allegro_api.models.external_id.ExternalId(
                    id = 'AH-129834', ), 
                delivery = allegro_api.models.offer_listing_dto_v1_delivery.OfferListingDtoV1Delivery(
                    shipping_rates = allegro_api.models.shipping_rates.ShippingRates(
                        id = '0', ), )
            )
        else :
            return OfferListingDto(
        )

    def testOfferListingDto(self):
        """Test OfferListingDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
